@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Loqui -- IRC client for Gtk2 <http://loqui.good-day.net/>
- * Copyright (C) 2002-2005 Yoichi Imai <yoichi@silver-forest.com>
+ * Loqui -- IRC client for Gtk2 <http://launchpad.net/loqui/>
+ * Copyright (C) 2002-2005 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ about_open(void)
 {
 	gtkutils_msgbox_info(GTK_MESSAGE_INFO,
 			     "%s\n"
-			     "IRC client for Gtk2\n"
-			     "Copyright (C) 2002-2005, Yoichi Imai <yoichi@silver-forest.com>\n"
-			     "http://loqui.good-day.net/", loqui_core_get_version_info(loqui_get_core()));
+			     "IRC Client for Gtk2\n"
+			     "Copyright (C) 2002-2010, Yoichi Imai <sunnyone41@gmail.com>\n"
+			     "http://launchpad.net/loqui/", loqui_core_get_version_info(loqui_get_core()));
 }
